@@ -49,9 +49,10 @@ void
 dlg_prop (FrWindow *window)
 {
 	DialogData *data;
-	GtkWidget  *ok_button;
 	GtkWidget  *label;
 	GFile      *parent;
+	char       *uri;
+	char       *markup;
 	char       *s;
 	goffset     size, uncompressed_size;
 	char       *utf8_name;
@@ -69,15 +70,19 @@ dlg_prop (FrWindow *window)
 	/* Get the widgets. */
 
 	data->dialog = _gtk_builder_get_widget (data->builder, "prop_dialog");
-	ok_button = _gtk_builder_get_widget (data->builder, "p_ok_button");
 
 	/* Set widgets data. */
 
 	label = _gtk_builder_get_widget (data->builder, "p_path_label");
 	parent = g_file_get_parent (fr_window_get_archive_file (window));
+	uri = g_file_get_uri (parent);
 	utf8_name = g_file_get_parse_name (parent);
-	gtk_label_set_text (GTK_LABEL (label), utf8_name);
+	markup = g_strdup_printf ("<a href=\"%s\">%s</a>", uri, utf8_name);
+	gtk_label_set_markup (GTK_LABEL (label), markup);
+
+	g_free (markup);
 	g_free (utf8_name);
+	g_free (uri);
 	g_object_unref (parent);
 
 	/**/
@@ -154,10 +159,6 @@ dlg_prop (FrWindow *window)
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
-	g_signal_connect_swapped (G_OBJECT (ok_button),
-				  "clicked",
-				  G_CALLBACK (gtk_widget_destroy),
-				  G_OBJECT (data->dialog));
 
 	/* Run dialog. */
 
